[llvm] r190345 - Rename for consistency.
Eric Christopher
echristo at gmail.com
Mon Sep 9 13:03:17 PDT 2013
Author: echristo
Date: Mon Sep 9 15:03:17 2013
New Revision: 190345
URL: http://llvm.org/viewvc/llvm-project?rev=190345&view=rev
Log:
Rename for consistency.
Modified:
llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp
llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h
Modified: llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp?rev=190345&r1=190344&r2=190345&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h (original)
+++ llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h Mon Sep 9 15:03:17 2013
@@ -527,7 +527,7 @@ private:
void emitAccelTypes();
/// \brief Emit visible names into a debug pubnames section.
- void emitDebugPubnames();
+ void emitDebugPubNames();
/// \brief Emit visible types into a debug pubtypes section.
void emitDebugPubTypes();
More information about the llvm-commits
mailing list
--- llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp (original)
+++ llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp Mon Sep 9 15:03:17 2013
@@ -1109,7 +1109,7 @@ void DwarfDebug::endModule() {
// Emit the pubnames and pubtypes sections if requested.
if (HasDwarfPubSections) {
- emitDebugPubnames();
+ emitDebugPubNames();
emitDebugPubTypes();
}
@@ -2252,9 +2252,9 @@ void DwarfDebug::emitAccelTypes() {
AT.Emit(Asm, SectionBegin, &InfoHolder);
}
/// emitDebugPubnames - Emit visible names into a debug pubnames section.
///
-void DwarfDebug::emitDebugPubnames() {
+void DwarfDebug::emitDebugPubNames() {
const MCSection *ISec = Asm->getObjFileLowering().getDwarfInfoSection();
typedef DenseMap<const MDNode*, CompileUnit*> CUMapType;
Modified: llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h
@@ -2252,9 +2252,9 @@ void DwarfDebug::emitAccelTypes() {
AT.Emit(Asm, SectionBegin, &InfoHolder);
}
-/// emitDebugPubnames - Emit visible names into a debug pubnames section.
+/// emitDebugPubNames - Emit visible names into a debug pubnames section.
///
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h?rev=190345&r1=190344&r2=190345&view=diff
==============================================================================